# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/config_dump.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.bootstrap.v2 import bootstrap_pb2 as envoy_dot_config_dot_bootstrap_dot_v2_dot_bootstrap__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v2alpha/config_dump.proto',
  package='envoy.admin.v2alpha',
  syntax='proto3',
  serialized_options=b'\n!io.envoyproxy.envoy.admin.v2alphaB\017ConfigDumpProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%envoy/admin/v2alpha/config_dump.proto\x12\x13\x65nvoy.admin.v2alpha\x1a)envoy/config/bootstrap/v2/bootstrap.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\"3\n\nConfigDump\x12%\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\"\x92\x01\n\x12UpdateFailureState\x12\x32\n\x14\x66\x61iled_configuration\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x37\n\x13last_update_attempt\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x64\x65tails\x18\x03 \x01(\t\"\x80\x01\n\x13\x42ootstrapConfigDump\x12\x37\n\tbootstrap\x18\x01 \x01(\x0b\x32$.envoy.config.bootstrap.v2.Bootstrap\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xaa\x06\n\x13ListenersConfigDump\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12Q\n\x10static_listeners\x18\x02 \x03(\x0b\x32\x37.envoy.admin.v2alpha.ListenersConfigDump.StaticListener\x12S\n\x11\x64ynamic_listeners\x18\x03 \x03(\x0b\x32\x38.envoy.admin.v2alpha.ListenersConfigDump.DynamicListener\x1aj\n\x0eStaticListener\x12&\n\x08listener\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x86\x01\n\x14\x44ynamicListenerState\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12&\n\x08listener\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xdf\x02\n\x0f\x44ynamicListener\x12\x0c\n\x04name\x18\x01 \x01(\t\x12S\n\x0c\x61\x63tive_state\x18\x02 \x01(\x0b\x32=.envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState\x12T\n\rwarming_state\x18\x03 \x01(\x0b\x32=.envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState\x12U\n\x0e\x64raining_state\x18\x04 \x01(\x0b\x32=.envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState\x12<\n\x0b\x65rror_state\x18\x05 \x01(\x0b\x32\'.envoy.admin.v2alpha.UpdateFailureState\"\x98\x04\n\x12\x43lustersConfigDump\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12N\n\x0fstatic_clusters\x18\x02 \x03(\x0b\x32\x35.envoy.admin.v2alpha.ClustersConfigDump.StaticCluster\x12W\n\x17\x64ynamic_active_clusters\x18\x03 \x03(\x0b\x32\x36.envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster\x12X\n\x18\x64ynamic_warming_clusters\x18\x04 \x03(\x0b\x32\x36.envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster\x1ah\n\rStaticCluster\x12%\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x7f\n\x0e\x44ynamicCluster\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12%\n\x07\x63luster\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xc0\x03\n\x10RoutesConfigDump\x12U\n\x14static_route_configs\x18\x02 \x03(\x0b\x32\x37.envoy.admin.v2alpha.RoutesConfigDump.StaticRouteConfig\x12W\n\x15\x64ynamic_route_configs\x18\x03 \x03(\x0b\x32\x38.envoy.admin.v2alpha.RoutesConfigDump.DynamicRouteConfig\x1aq\n\x11StaticRouteConfig\x12*\n\x0croute_config\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x88\x01\n\x12\x44ynamicRouteConfig\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12*\n\x0croute_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa9\x04\n\x16ScopedRoutesConfigDump\x12i\n\x1binline_scoped_route_configs\x18\x01 \x03(\x0b\x32\x44.envoy.admin.v2alpha.ScopedRoutesConfigDump.InlineScopedRouteConfigs\x12k\n\x1c\x64ynamic_scoped_route_configs\x18\x02 \x03(\x0b\x32\x45.envoy.admin.v2alpha.ScopedRoutesConfigDump.DynamicScopedRouteConfigs\x1a\x8e\x01\n\x18InlineScopedRouteConfigs\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x32\n\x14scoped_route_configs\x18\x02 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xa5\x01\n\x19\x44ynamicScopedRouteConfigs\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cversion_info\x18\x02 \x01(\t\x12\x32\n\x14scoped_route_configs\x18\x03 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x91\x04\n\x11SecretsConfigDump\x12K\n\x0estatic_secrets\x18\x01 \x03(\x0b\x32\x33.envoy.admin.v2alpha.SecretsConfigDump.StaticSecret\x12T\n\x16\x64ynamic_active_secrets\x18\x02 \x03(\x0b\x32\x34.envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret\x12U\n\x17\x64ynamic_warming_secrets\x18\x03 \x03(\x0b\x32\x34.envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret\x1a\x8b\x01\n\rDynamicSecret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cversion_info\x18\x02 \x01(\t\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x06secret\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x1at\n\x0cStaticSecret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x06secret\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB>\n!io.envoyproxy.envoy.admin.v2alphaB\x0f\x43onfigDumpProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_bootstrap_dot_v2_dot_bootstrap__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_CONFIGDUMP = _descriptor.Descriptor(
  name='ConfigDump',
  full_name='envoy.admin.v2alpha.ConfigDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='configs', full_name='envoy.admin.v2alpha.ConfigDump.configs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=247,
)


_UPDATEFAILURESTATE = _descriptor.Descriptor(
  name='UpdateFailureState',
  full_name='envoy.admin.v2alpha.UpdateFailureState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='failed_configuration', full_name='envoy.admin.v2alpha.UpdateFailureState.failed_configuration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update_attempt', full_name='envoy.admin.v2alpha.UpdateFailureState.last_update_attempt', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='envoy.admin.v2alpha.UpdateFailureState.details', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=396,
)


_BOOTSTRAPCONFIGDUMP = _descriptor.Descriptor(
  name='BootstrapConfigDump',
  full_name='envoy.admin.v2alpha.BootstrapConfigDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bootstrap', full_name='envoy.admin.v2alpha.BootstrapConfigDump.bootstrap', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.BootstrapConfigDump.last_updated', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=527,
)


_LISTENERSCONFIGDUMP_STATICLISTENER = _descriptor.Descriptor(
  name='StaticListener',
  full_name='envoy.admin.v2alpha.ListenersConfigDump.StaticListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='listener', full_name='envoy.admin.v2alpha.ListenersConfigDump.StaticListener.listener', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.ListenersConfigDump.StaticListener.last_updated', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=743,
  serialized_end=849,
)

_LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE = _descriptor.Descriptor(
  name='DynamicListenerState',
  full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState.version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState.listener', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState.last_updated', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=852,
  serialized_end=986,
)

_LISTENERSCONFIGDUMP_DYNAMICLISTENER = _descriptor.Descriptor(
  name='DynamicListener',
  full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListener.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_state', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListener.active_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warming_state', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListener.warming_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='draining_state', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListener.draining_state', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_state', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListener.error_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=989,
  serialized_end=1340,
)

_LISTENERSCONFIGDUMP = _descriptor.Descriptor(
  name='ListenersConfigDump',
  full_name='envoy.admin.v2alpha.ListenersConfigDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.admin.v2alpha.ListenersConfigDump.version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_listeners', full_name='envoy.admin.v2alpha.ListenersConfigDump.static_listeners', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_listeners', full_name='envoy.admin.v2alpha.ListenersConfigDump.dynamic_listeners', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTENERSCONFIGDUMP_STATICLISTENER, _LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE, _LISTENERSCONFIGDUMP_DYNAMICLISTENER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=530,
  serialized_end=1340,
)


_CLUSTERSCONFIGDUMP_STATICCLUSTER = _descriptor.Descriptor(
  name='StaticCluster',
  full_name='envoy.admin.v2alpha.ClustersConfigDump.StaticCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.admin.v2alpha.ClustersConfigDump.StaticCluster.cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.ClustersConfigDump.StaticCluster.last_updated', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1646,
  serialized_end=1750,
)

_CLUSTERSCONFIGDUMP_DYNAMICCLUSTER = _descriptor.Descriptor(
  name='DynamicCluster',
  full_name='envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster.version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster.cluster', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster.last_updated', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1752,
  serialized_end=1879,
)

_CLUSTERSCONFIGDUMP = _descriptor.Descriptor(
  name='ClustersConfigDump',
  full_name='envoy.admin.v2alpha.ClustersConfigDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.admin.v2alpha.ClustersConfigDump.version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_clusters', full_name='envoy.admin.v2alpha.ClustersConfigDump.static_clusters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_active_clusters', full_name='envoy.admin.v2alpha.ClustersConfigDump.dynamic_active_clusters', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_warming_clusters', full_name='envoy.admin.v2alpha.ClustersConfigDump.dynamic_warming_clusters', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTERSCONFIGDUMP_STATICCLUSTER, _CLUSTERSCONFIGDUMP_DYNAMICCLUSTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1343,
  serialized_end=1879,
)


_ROUTESCONFIGDUMP_STATICROUTECONFIG = _descriptor.Descriptor(
  name='StaticRouteConfig',
  full_name='envoy.admin.v2alpha.RoutesConfigDump.StaticRouteConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='route_config', full_name='envoy.admin.v2alpha.RoutesConfigDump.StaticRouteConfig.route_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.RoutesConfigDump.StaticRouteConfig.last_updated', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2078,
  serialized_end=2191,
)

_ROUTESCONFIGDUMP_DYNAMICROUTECONFIG = _descriptor.Descriptor(
  name='DynamicRouteConfig',
  full_name='envoy.admin.v2alpha.RoutesConfigDump.DynamicRouteConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.admin.v2alpha.RoutesConfigDump.DynamicRouteConfig.version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_config', full_name='envoy.admin.v2alpha.RoutesConfigDump.DynamicRouteConfig.route_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.RoutesConfigDump.DynamicRouteConfig.last_updated', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2194,
  serialized_end=2330,
)

_ROUTESCONFIGDUMP = _descriptor.Descriptor(
  name='RoutesConfigDump',
  full_name='envoy.admin.v2alpha.RoutesConfigDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='static_route_configs', full_name='envoy.admin.v2alpha.RoutesConfigDump.static_route_configs', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_route_configs', full_name='envoy.admin.v2alpha.RoutesConfigDump.dynamic_route_configs', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ROUTESCONFIGDUMP_STATICROUTECONFIG, _ROUTESCONFIGDUMP_DYNAMICROUTECONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1882,
  serialized_end=2330,
)


_SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS = _descriptor.Descriptor(
  name='InlineScopedRouteConfigs',
  full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.InlineScopedRouteConfigs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.InlineScopedRouteConfigs.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoped_route_configs', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.InlineScopedRouteConfigs.scoped_route_configs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.InlineScopedRouteConfigs.last_updated', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2576,
  serialized_end=2718,
)

_SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS = _descriptor.Descriptor(
  name='DynamicScopedRouteConfigs',
  full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.DynamicScopedRouteConfigs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.DynamicScopedRouteConfigs.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.DynamicScopedRouteConfigs.version_info', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoped_route_configs', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.DynamicScopedRouteConfigs.scoped_route_configs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.DynamicScopedRouteConfigs.last_updated', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2721,
  serialized_end=2886,
)

_SCOPEDROUTESCONFIGDUMP = _descriptor.Descriptor(
  name='ScopedRoutesConfigDump',
  full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inline_scoped_route_configs', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.inline_scoped_route_configs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_scoped_route_configs', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.dynamic_scoped_route_configs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS, _SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2333,
  serialized_end=2886,
)


_SECRETSCONFIGDUMP_DYNAMICSECRET = _descriptor.Descriptor(
  name='DynamicSecret',
  full_name='envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret.version_info', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret.last_updated', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret.secret', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3161,
  serialized_end=3300,
)

_SECRETSCONFIGDUMP_STATICSECRET = _descriptor.Descriptor(
  name='StaticSecret',
  full_name='envoy.admin.v2alpha.SecretsConfigDump.StaticSecret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v2alpha.SecretsConfigDump.StaticSecret.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.SecretsConfigDump.StaticSecret.last_updated', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='envoy.admin.v2alpha.SecretsConfigDump.StaticSecret.secret', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3302,
  serialized_end=3418,
)

_SECRETSCONFIGDUMP = _descriptor.Descriptor(
  name='SecretsConfigDump',
  full_name='envoy.admin.v2alpha.SecretsConfigDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='static_secrets', full_name='envoy.admin.v2alpha.SecretsConfigDump.static_secrets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_active_secrets', full_name='envoy.admin.v2alpha.SecretsConfigDump.dynamic_active_secrets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_warming_secrets', full_name='envoy.admin.v2alpha.SecretsConfigDump.dynamic_warming_secrets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SECRETSCONFIGDUMP_DYNAMICSECRET, _SECRETSCONFIGDUMP_STATICSECRET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2889,
  serialized_end=3418,
)

_CONFIGDUMP.fields_by_name['configs'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_UPDATEFAILURESTATE.fields_by_name['failed_configuration'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_UPDATEFAILURESTATE.fields_by_name['last_update_attempt'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BOOTSTRAPCONFIGDUMP.fields_by_name['bootstrap'].message_type = envoy_dot_config_dot_bootstrap_dot_v2_dot_bootstrap__pb2._BOOTSTRAP
_BOOTSTRAPCONFIGDUMP.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTENERSCONFIGDUMP_STATICLISTENER.fields_by_name['listener'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_LISTENERSCONFIGDUMP_STATICLISTENER.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTENERSCONFIGDUMP_STATICLISTENER.containing_type = _LISTENERSCONFIGDUMP
_LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE.fields_by_name['listener'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE.containing_type = _LISTENERSCONFIGDUMP
_LISTENERSCONFIGDUMP_DYNAMICLISTENER.fields_by_name['active_state'].message_type = _LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE
_LISTENERSCONFIGDUMP_DYNAMICLISTENER.fields_by_name['warming_state'].message_type = _LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE
_LISTENERSCONFIGDUMP_DYNAMICLISTENER.fields_by_name['draining_state'].message_type = _LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE
_LISTENERSCONFIGDUMP_DYNAMICLISTENER.fields_by_name['error_state'].message_type = _UPDATEFAILURESTATE
_LISTENERSCONFIGDUMP_DYNAMICLISTENER.containing_type = _LISTENERSCONFIGDUMP
_LISTENERSCONFIGDUMP.fields_by_name['static_listeners'].message_type = _LISTENERSCONFIGDUMP_STATICLISTENER
_LISTENERSCONFIGDUMP.fields_by_name['dynamic_listeners'].message_type = _LISTENERSCONFIGDUMP_DYNAMICLISTENER
_CLUSTERSCONFIGDUMP_STATICCLUSTER.fields_by_name['cluster'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CLUSTERSCONFIGDUMP_STATICCLUSTER.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CLUSTERSCONFIGDUMP_STATICCLUSTER.containing_type = _CLUSTERSCONFIGDUMP
_CLUSTERSCONFIGDUMP_DYNAMICCLUSTER.fields_by_name['cluster'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CLUSTERSCONFIGDUMP_DYNAMICCLUSTER.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CLUSTERSCONFIGDUMP_DYNAMICCLUSTER.containing_type = _CLUSTERSCONFIGDUMP
_CLUSTERSCONFIGDUMP.fields_by_name['static_clusters'].message_type = _CLUSTERSCONFIGDUMP_STATICCLUSTER
_CLUSTERSCONFIGDUMP.fields_by_name['dynamic_active_clusters'].message_type = _CLUSTERSCONFIGDUMP_DYNAMICCLUSTER
_CLUSTERSCONFIGDUMP.fields_by_name['dynamic_warming_clusters'].message_type = _CLUSTERSCONFIGDUMP_DYNAMICCLUSTER
_ROUTESCONFIGDUMP_STATICROUTECONFIG.fields_by_name['route_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ROUTESCONFIGDUMP_STATICROUTECONFIG.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ROUTESCONFIGDUMP_STATICROUTECONFIG.containing_type = _ROUTESCONFIGDUMP
_ROUTESCONFIGDUMP_DYNAMICROUTECONFIG.fields_by_name['route_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ROUTESCONFIGDUMP_DYNAMICROUTECONFIG.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ROUTESCONFIGDUMP_DYNAMICROUTECONFIG.containing_type = _ROUTESCONFIGDUMP
_ROUTESCONFIGDUMP.fields_by_name['static_route_configs'].message_type = _ROUTESCONFIGDUMP_STATICROUTECONFIG
_ROUTESCONFIGDUMP.fields_by_name['dynamic_route_configs'].message_type = _ROUTESCONFIGDUMP_DYNAMICROUTECONFIG
_SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS.fields_by_name['scoped_route_configs'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS.containing_type = _SCOPEDROUTESCONFIGDUMP
_SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS.fields_by_name['scoped_route_configs'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS.containing_type = _SCOPEDROUTESCONFIGDUMP
_SCOPEDROUTESCONFIGDUMP.fields_by_name['inline_scoped_route_configs'].message_type = _SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS
_SCOPEDROUTESCONFIGDUMP.fields_by_name['dynamic_scoped_route_configs'].message_type = _SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS
_SECRETSCONFIGDUMP_DYNAMICSECRET.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SECRETSCONFIGDUMP_DYNAMICSECRET.fields_by_name['secret'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SECRETSCONFIGDUMP_DYNAMICSECRET.containing_type = _SECRETSCONFIGDUMP
_SECRETSCONFIGDUMP_STATICSECRET.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SECRETSCONFIGDUMP_STATICSECRET.fields_by_name['secret'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SECRETSCONFIGDUMP_STATICSECRET.containing_type = _SECRETSCONFIGDUMP
_SECRETSCONFIGDUMP.fields_by_name['static_secrets'].message_type = _SECRETSCONFIGDUMP_STATICSECRET
_SECRETSCONFIGDUMP.fields_by_name['dynamic_active_secrets'].message_type = _SECRETSCONFIGDUMP_DYNAMICSECRET
_SECRETSCONFIGDUMP.fields_by_name['dynamic_warming_secrets'].message_type = _SECRETSCONFIGDUMP_DYNAMICSECRET
DESCRIPTOR.message_types_by_name['ConfigDump'] = _CONFIGDUMP
DESCRIPTOR.message_types_by_name['UpdateFailureState'] = _UPDATEFAILURESTATE
DESCRIPTOR.message_types_by_name['BootstrapConfigDump'] = _BOOTSTRAPCONFIGDUMP
DESCRIPTOR.message_types_by_name['ListenersConfigDump'] = _LISTENERSCONFIGDUMP
DESCRIPTOR.message_types_by_name['ClustersConfigDump'] = _CLUSTERSCONFIGDUMP
DESCRIPTOR.message_types_by_name['RoutesConfigDump'] = _ROUTESCONFIGDUMP
DESCRIPTOR.message_types_by_name['ScopedRoutesConfigDump'] = _SCOPEDROUTESCONFIGDUMP
DESCRIPTOR.message_types_by_name['SecretsConfigDump'] = _SECRETSCONFIGDUMP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConfigDump = _reflection.GeneratedProtocolMessageType('ConfigDump', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGDUMP,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ConfigDump)
  })
_sym_db.RegisterMessage(ConfigDump)

UpdateFailureState = _reflection.GeneratedProtocolMessageType('UpdateFailureState', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFAILURESTATE,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.UpdateFailureState)
  })
_sym_db.RegisterMessage(UpdateFailureState)

BootstrapConfigDump = _reflection.GeneratedProtocolMessageType('BootstrapConfigDump', (_message.Message,), {
  'DESCRIPTOR' : _BOOTSTRAPCONFIGDUMP,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.BootstrapConfigDump)
  })
_sym_db.RegisterMessage(BootstrapConfigDump)

ListenersConfigDump = _reflection.GeneratedProtocolMessageType('ListenersConfigDump', (_message.Message,), {

  'StaticListener' : _reflection.GeneratedProtocolMessageType('StaticListener', (_message.Message,), {
    'DESCRIPTOR' : _LISTENERSCONFIGDUMP_STATICLISTENER,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ListenersConfigDump.StaticListener)
    })
  ,

  'DynamicListenerState' : _reflection.GeneratedProtocolMessageType('DynamicListenerState', (_message.Message,), {
    'DESCRIPTOR' : _LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState)
    })
  ,

  'DynamicListener' : _reflection.GeneratedProtocolMessageType('DynamicListener', (_message.Message,), {
    'DESCRIPTOR' : _LISTENERSCONFIGDUMP_DYNAMICLISTENER,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ListenersConfigDump.DynamicListener)
    })
  ,
  'DESCRIPTOR' : _LISTENERSCONFIGDUMP,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ListenersConfigDump)
  })
_sym_db.RegisterMessage(ListenersConfigDump)
_sym_db.RegisterMessage(ListenersConfigDump.StaticListener)
_sym_db.RegisterMessage(ListenersConfigDump.DynamicListenerState)
_sym_db.RegisterMessage(ListenersConfigDump.DynamicListener)

ClustersConfigDump = _reflection.GeneratedProtocolMessageType('ClustersConfigDump', (_message.Message,), {

  'StaticCluster' : _reflection.GeneratedProtocolMessageType('StaticCluster', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERSCONFIGDUMP_STATICCLUSTER,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ClustersConfigDump.StaticCluster)
    })
  ,

  'DynamicCluster' : _reflection.GeneratedProtocolMessageType('DynamicCluster', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERSCONFIGDUMP_DYNAMICCLUSTER,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster)
    })
  ,
  'DESCRIPTOR' : _CLUSTERSCONFIGDUMP,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ClustersConfigDump)
  })
_sym_db.RegisterMessage(ClustersConfigDump)
_sym_db.RegisterMessage(ClustersConfigDump.StaticCluster)
_sym_db.RegisterMessage(ClustersConfigDump.DynamicCluster)

RoutesConfigDump = _reflection.GeneratedProtocolMessageType('RoutesConfigDump', (_message.Message,), {

  'StaticRouteConfig' : _reflection.GeneratedProtocolMessageType('StaticRouteConfig', (_message.Message,), {
    'DESCRIPTOR' : _ROUTESCONFIGDUMP_STATICROUTECONFIG,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.RoutesConfigDump.StaticRouteConfig)
    })
  ,

  'DynamicRouteConfig' : _reflection.GeneratedProtocolMessageType('DynamicRouteConfig', (_message.Message,), {
    'DESCRIPTOR' : _ROUTESCONFIGDUMP_DYNAMICROUTECONFIG,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.RoutesConfigDump.DynamicRouteConfig)
    })
  ,
  'DESCRIPTOR' : _ROUTESCONFIGDUMP,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.RoutesConfigDump)
  })
_sym_db.RegisterMessage(RoutesConfigDump)
_sym_db.RegisterMessage(RoutesConfigDump.StaticRouteConfig)
_sym_db.RegisterMessage(RoutesConfigDump.DynamicRouteConfig)

ScopedRoutesConfigDump = _reflection.GeneratedProtocolMessageType('ScopedRoutesConfigDump', (_message.Message,), {

  'InlineScopedRouteConfigs' : _reflection.GeneratedProtocolMessageType('InlineScopedRouteConfigs', (_message.Message,), {
    'DESCRIPTOR' : _SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ScopedRoutesConfigDump.InlineScopedRouteConfigs)
    })
  ,

  'DynamicScopedRouteConfigs' : _reflection.GeneratedProtocolMessageType('DynamicScopedRouteConfigs', (_message.Message,), {
    'DESCRIPTOR' : _SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ScopedRoutesConfigDump.DynamicScopedRouteConfigs)
    })
  ,
  'DESCRIPTOR' : _SCOPEDROUTESCONFIGDUMP,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ScopedRoutesConfigDump)
  })
_sym_db.RegisterMessage(ScopedRoutesConfigDump)
_sym_db.RegisterMessage(ScopedRoutesConfigDump.InlineScopedRouteConfigs)
_sym_db.RegisterMessage(ScopedRoutesConfigDump.DynamicScopedRouteConfigs)

SecretsConfigDump = _reflection.GeneratedProtocolMessageType('SecretsConfigDump', (_message.Message,), {

  'DynamicSecret' : _reflection.GeneratedProtocolMessageType('DynamicSecret', (_message.Message,), {
    'DESCRIPTOR' : _SECRETSCONFIGDUMP_DYNAMICSECRET,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret)
    })
  ,

  'StaticSecret' : _reflection.GeneratedProtocolMessageType('StaticSecret', (_message.Message,), {
    'DESCRIPTOR' : _SECRETSCONFIGDUMP_STATICSECRET,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.SecretsConfigDump.StaticSecret)
    })
  ,
  'DESCRIPTOR' : _SECRETSCONFIGDUMP,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.SecretsConfigDump)
  })
_sym_db.RegisterMessage(SecretsConfigDump)
_sym_db.RegisterMessage(SecretsConfigDump.DynamicSecret)
_sym_db.RegisterMessage(SecretsConfigDump.StaticSecret)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/rbac/v4alpha/rbac.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.rbac.v4alpha import rbac_pb2 as envoy_dot_config_dot_rbac_dot_v4alpha_dot_rbac__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/rbac/v4alpha/rbac.proto',
  package='envoy.extensions.filters.http.rbac.v4alpha',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.extensions.filters.http.rbac.v4alphaB\tRbacProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5envoy/extensions/filters/http/rbac/v4alpha/rbac.proto\x12*envoy.extensions.filters.http.rbac.v4alpha\x1a$envoy/config/rbac/v4alpha/rbac.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xa0\x01\n\x04RBAC\x12.\n\x05rules\x18\x01 \x01(\x0b\x32\x1f.envoy.config.rbac.v4alpha.RBAC\x12\x35\n\x0cshadow_rules\x18\x02 \x01(\x0b\x32\x1f.envoy.config.rbac.v4alpha.RBAC:1\x9a\xc5\x88\x1e,\n*envoy.extensions.filters.http.rbac.v3.RBAC\"\x8f\x01\n\x0cRBACPerRoute\x12>\n\x04rbac\x18\x02 \x01(\x0b\x32\x30.envoy.extensions.filters.http.rbac.v4alpha.RBAC:9\x9a\xc5\x88\x1e\x34\n2envoy.extensions.filters.http.rbac.v3.RBACPerRouteJ\x04\x08\x01\x10\x02\x42O\n8io.envoyproxy.envoy.extensions.filters.http.rbac.v4alphaB\tRbacProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_rbac_dot_v4alpha_dot_rbac__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_RBAC = _descriptor.Descriptor(
  name='RBAC',
  full_name='envoy.extensions.filters.http.rbac.v4alpha.RBAC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='envoy.extensions.filters.http.rbac.v4alpha.RBAC.rules', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shadow_rules', full_name='envoy.extensions.filters.http.rbac.v4alpha.RBAC.shadow_rules', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.extensions.filters.http.rbac.v3.RBAC',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=366,
)


_RBACPERROUTE = _descriptor.Descriptor(
  name='RBACPerRoute',
  full_name='envoy.extensions.filters.http.rbac.v4alpha.RBACPerRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rbac', full_name='envoy.extensions.filters.http.rbac.v4alpha.RBACPerRoute.rbac', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.extensions.filters.http.rbac.v3.RBACPerRoute',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=512,
)

_RBAC.fields_by_name['rules'].message_type = envoy_dot_config_dot_rbac_dot_v4alpha_dot_rbac__pb2._RBAC
_RBAC.fields_by_name['shadow_rules'].message_type = envoy_dot_config_dot_rbac_dot_v4alpha_dot_rbac__pb2._RBAC
_RBACPERROUTE.fields_by_name['rbac'].message_type = _RBAC
DESCRIPTOR.message_types_by_name['RBAC'] = _RBAC
DESCRIPTOR.message_types_by_name['RBACPerRoute'] = _RBACPERROUTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RBAC = _reflection.GeneratedProtocolMessageType('RBAC', (_message.Message,), {
  'DESCRIPTOR' : _RBAC,
  '__module__' : 'envoy.extensions.filters.http.rbac.v4alpha.rbac_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.rbac.v4alpha.RBAC)
  })
_sym_db.RegisterMessage(RBAC)

RBACPerRoute = _reflection.GeneratedProtocolMessageType('RBACPerRoute', (_message.Message,), {
  'DESCRIPTOR' : _RBACPERROUTE,
  '__module__' : 'envoy.extensions.filters.http.rbac.v4alpha.rbac_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.rbac.v4alpha.RBACPerRoute)
  })
_sym_db.RegisterMessage(RBACPerRoute)


DESCRIPTOR._options = None
_RBAC._options = None
_RBACPERROUTE._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/quic/v3/quic_transport.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.transport_sockets.tls.v3 import tls_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/transport_sockets/quic/v3/quic_transport.proto',
  package='envoy.extensions.transport_sockets.quic.v3',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.extensions.transport_sockets.quic.v3B\022QuicTransportProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?envoy/extensions/transport_sockets/quic/v3/quic_transport.proto\x12*envoy.extensions.transport_sockets.quic.v3\x1a\x33\x65nvoy/extensions/transport_sockets/tls/v3/tls.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x84\x01\n\x17QuicDownstreamTransport\x12i\n\x16\x64ownstream_tls_context\x18\x01 \x01(\x0b\x32?.envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContextB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"~\n\x15QuicUpstreamTransport\x12\x65\n\x14upstream_tls_context\x18\x01 \x01(\x0b\x32=.envoy.extensions.transport_sockets.tls.v3.UpstreamTlsContextB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42X\n8io.envoyproxy.envoy.extensions.transport_sockets.quic.v3B\x12QuicTransportProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_QUICDOWNSTREAMTRANSPORT = _descriptor.Descriptor(
  name='QuicDownstreamTransport',
  full_name='envoy.extensions.transport_sockets.quic.v3.QuicDownstreamTransport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='downstream_tls_context', full_name='envoy.extensions.transport_sockets.quic.v3.QuicDownstreamTransport.downstream_tls_context', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=353,
)


_QUICUPSTREAMTRANSPORT = _descriptor.Descriptor(
  name='QuicUpstreamTransport',
  full_name='envoy.extensions.transport_sockets.quic.v3.QuicUpstreamTransport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upstream_tls_context', full_name='envoy.extensions.transport_sockets.quic.v3.QuicUpstreamTransport.upstream_tls_context', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=481,
)

_QUICDOWNSTREAMTRANSPORT.fields_by_name['downstream_tls_context'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2._DOWNSTREAMTLSCONTEXT
_QUICUPSTREAMTRANSPORT.fields_by_name['upstream_tls_context'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2._UPSTREAMTLSCONTEXT
DESCRIPTOR.message_types_by_name['QuicDownstreamTransport'] = _QUICDOWNSTREAMTRANSPORT
DESCRIPTOR.message_types_by_name['QuicUpstreamTransport'] = _QUICUPSTREAMTRANSPORT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QuicDownstreamTransport = _reflection.GeneratedProtocolMessageType('QuicDownstreamTransport', (_message.Message,), {
  'DESCRIPTOR' : _QUICDOWNSTREAMTRANSPORT,
  '__module__' : 'envoy.extensions.transport_sockets.quic.v3.quic_transport_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.quic.v3.QuicDownstreamTransport)
  })
_sym_db.RegisterMessage(QuicDownstreamTransport)

QuicUpstreamTransport = _reflection.GeneratedProtocolMessageType('QuicUpstreamTransport', (_message.Message,), {
  'DESCRIPTOR' : _QUICUPSTREAMTRANSPORT,
  '__module__' : 'envoy.extensions.transport_sockets.quic.v3.quic_transport_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.quic.v3.QuicUpstreamTransport)
  })
_sym_db.RegisterMessage(QuicUpstreamTransport)


DESCRIPTOR._options = None
_QUICDOWNSTREAMTRANSPORT.fields_by_name['downstream_tls_context']._options = None
_QUICUPSTREAMTRANSPORT.fields_by_name['upstream_tls_context']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/lds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from envoy.api.v2 import listener_pb2 as envoy_dot_api_dot_v2_dot_listener__pb2

from envoy.api.v2.listener_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/lds.proto',
  package='envoy.api.v2',
  syntax='proto3',
  serialized_options=b'\n\032io.envoyproxy.envoy.api.v2B\010LdsProtoP\001\210\001\001\362\230\376\217\005\033\022\031envoy.service.listener.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16\x65nvoy/api/v2/lds.proto\x12\x0c\x65nvoy.api.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x1b\x65nvoy/api/v2/listener.proto\"\n\n\x08LdsDummy2\xf3\x02\n\x18ListenerDiscoveryService\x12\x61\n\x0e\x44\x65ltaListeners\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12X\n\x0fStreamListeners\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12{\n\x0e\x46\x65tchListeners\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"(\x82\xd3\xe4\x93\x02\x19\"\x17/v2/discovery:listeners\x82\xd3\xe4\x93\x02\x03:\x01*\x1a\x1d\x8a\xa4\x96\xf3\x07\x17\n\x15\x65nvoy.api.v2.ListenerBT\n\x1aio.envoyproxy.envoy.api.v2B\x08LdsProtoP\x01\x88\x01\x01\xf2\x98\xfe\x8f\x05\x1b\x12\x19\x65nvoy.service.listener.v3\xba\x80\xc8\xd1\x06\x02\x10\x01P\x05\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_listener__pb2.DESCRIPTOR,],
  public_dependencies=[envoy_dot_api_dot_v2_dot_listener__pb2.DESCRIPTOR,])




_LDSDUMMY = _descriptor.Descriptor(
  name='LdsDummy',
  full_name='envoy.api.v2.LdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=236,
)

DESCRIPTOR.message_types_by_name['LdsDummy'] = _LDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LdsDummy = _reflection.GeneratedProtocolMessageType('LdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _LDSDUMMY,
  '__module__' : 'envoy.api.v2.lds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.LdsDummy)
  })
_sym_db.RegisterMessage(LdsDummy)


DESCRIPTOR._options = None

_LISTENERDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='ListenerDiscoveryService',
  full_name='envoy.api.v2.ListenerDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007\027\n\025envoy.api.v2.Listener',
  create_key=_descriptor._internal_create_key,
  serialized_start=239,
  serialized_end=610,
  methods=[
  _descriptor.MethodDescriptor(
    name='DeltaListeners',
    full_name='envoy.api.v2.ListenerDiscoveryService.DeltaListeners',
    index=0,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamListeners',
    full_name='envoy.api.v2.ListenerDiscoveryService.StreamListeners',
    index=1,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchListeners',
    full_name='envoy.api.v2.ListenerDiscoveryService.FetchListeners',
    index=2,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\"\027/v2/discovery:listeners\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LISTENERDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['ListenerDiscoveryService'] = _LISTENERDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/cluster/circuit_breaker.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/cluster/circuit_breaker.proto',
  package='envoy.api.v2.cluster',
  syntax='proto3',
  serialized_options=b'\n\"io.envoyproxy.envoy.api.v2.clusterB\023CircuitBreakerProtoP\001\252\002\026Envoy.Api.V2.ClusterNS\352\002\026Envoy.Api.V2.ClusterNS\362\230\376\217\005\031\022\027envoy.config.cluster.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*envoy/api/v2/cluster/circuit_breaker.proto\x12\x14\x65nvoy.api.v2.cluster\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x18\x65nvoy/type/percent.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa2\x05\n\x0f\x43ircuitBreakers\x12\x44\n\nthresholds\x18\x01 \x03(\x0b\x32\x30.envoy.api.v2.cluster.CircuitBreakers.Thresholds\x1a\xc8\x04\n\nThresholds\x12>\n\x08priority\x18\x01 \x01(\x0e\x32\".envoy.api.v2.core.RoutingPriorityB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x35\n\x0fmax_connections\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12:\n\x14max_pending_requests\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x32\n\x0cmax_requests\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x31\n\x0bmax_retries\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12R\n\x0cretry_budget\x18\x08 \x01(\x0b\x32<.envoy.api.v2.cluster.CircuitBreakers.Thresholds.RetryBudget\x12\x17\n\x0ftrack_remaining\x18\x06 \x01(\x08\x12:\n\x14max_connection_pools\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x1aw\n\x0bRetryBudget\x12+\n\x0e\x62udget_percent\x18\x01 \x01(\x0b\x32\x13.envoy.type.Percent\x12;\n\x15min_retry_concurrency\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x94\x01\n\"io.envoyproxy.envoy.api.v2.clusterB\x13\x43ircuitBreakerProtoP\x01\xaa\x02\x16\x45nvoy.Api.V2.ClusterNS\xea\x02\x16\x45nvoy.Api.V2.ClusterNS\xf2\x98\xfe\x8f\x05\x19\x12\x17\x65nvoy.config.cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_type_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET = _descriptor.Descriptor(
  name='RetryBudget',
  full_name='envoy.api.v2.cluster.CircuitBreakers.Thresholds.RetryBudget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='budget_percent', full_name='envoy.api.v2.cluster.CircuitBreakers.Thresholds.RetryBudget.budget_percent', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_retry_concurrency', full_name='envoy.api.v2.cluster.CircuitBreakers.Thresholds.RetryBudget.min_retry_concurrency', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=800,
  serialized_end=919,
)

_CIRCUITBREAKERS_THRESHOLDS = _descriptor.Descriptor(
  name='Thresholds',
  full_name='envoy.api.v2.cluster.CircuitBreakers.Thresholds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='priority', full_name='envoy.api.v2.cluster.CircuitBreakers.Thresholds.priority', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_connections', full_name='envoy.api.v2.cluster.CircuitBreakers.Thresholds.max_connections', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_pending_requests', full_name='envoy.api.v2.cluster.CircuitBreakers.Thresholds.max_pending_requests', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_requests', full_name='envoy.api.v2.cluster.CircuitBreakers.Thresholds.max_requests', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_retries', full_name='envoy.api.v2.cluster.CircuitBreakers.Thresholds.max_retries', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retry_budget', full_name='envoy.api.v2.cluster.CircuitBreakers.Thresholds.retry_budget', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='track_remaining', full_name='envoy.api.v2.cluster.CircuitBreakers.Thresholds.track_remaining', index=6,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_connection_pools', full_name='envoy.api.v2.cluster.CircuitBreakers.Thresholds.max_connection_pools', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=919,
)

_CIRCUITBREAKERS = _descriptor.Descriptor(
  name='CircuitBreakers',
  full_name='envoy.api.v2.cluster.CircuitBreakers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='thresholds', full_name='envoy.api.v2.cluster.CircuitBreakers.thresholds', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CIRCUITBREAKERS_THRESHOLDS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=919,
)

_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET.fields_by_name['budget_percent'].message_type = envoy_dot_type_dot_percent__pb2._PERCENT
_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET.fields_by_name['min_retry_concurrency'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET.containing_type = _CIRCUITBREAKERS_THRESHOLDS
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['priority'].enum_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._ROUTINGPRIORITY
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['max_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['max_pending_requests'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['max_requests'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['max_retries'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['retry_budget'].message_type = _CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['max_connection_pools'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CIRCUITBREAKERS_THRESHOLDS.containing_type = _CIRCUITBREAKERS
_CIRCUITBREAKERS.fields_by_name['thresholds'].message_type = _CIRCUITBREAKERS_THRESHOLDS
DESCRIPTOR.message_types_by_name['CircuitBreakers'] = _CIRCUITBREAKERS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CircuitBreakers = _reflection.GeneratedProtocolMessageType('CircuitBreakers', (_message.Message,), {

  'Thresholds' : _reflection.GeneratedProtocolMessageType('Thresholds', (_message.Message,), {

    'RetryBudget' : _reflection.GeneratedProtocolMessageType('RetryBudget', (_message.Message,), {
      'DESCRIPTOR' : _CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET,
      '__module__' : 'envoy.api.v2.cluster.circuit_breaker_pb2'
      # @@protoc_insertion_point(class_scope:envoy.api.v2.cluster.CircuitBreakers.Thresholds.RetryBudget)
      })
    ,
    'DESCRIPTOR' : _CIRCUITBREAKERS_THRESHOLDS,
    '__module__' : 'envoy.api.v2.cluster.circuit_breaker_pb2'
    # @@protoc_insertion_point(class_scope:envoy.api.v2.cluster.CircuitBreakers.Thresholds)
    })
  ,
  'DESCRIPTOR' : _CIRCUITBREAKERS,
  '__module__' : 'envoy.api.v2.cluster.circuit_breaker_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.cluster.CircuitBreakers)
  })
_sym_db.RegisterMessage(CircuitBreakers)
_sym_db.RegisterMessage(CircuitBreakers.Thresholds)
_sym_db.RegisterMessage(CircuitBreakers.Thresholds.RetryBudget)


DESCRIPTOR._options = None
_CIRCUITBREAKERS_THRESHOLDS.fields_by_name['priority']._options = None
# @@protoc_insertion_point(module_scope)
